@@ -2,7 +2,7 @@
 # Euclidean distance
 
 EuclideanDistance <- function(x, y) {
-  if (class(try(LPInitialCheck(x, y))) == "try-error") {
+  if (is(try(LPInitialCheck(x, y)))[1] == "try-error") {
     return(NA)
   } else {
   d <- as.numeric(dist(rbind(x, y), "euclidean")) 
@@ -13,7 +13,7 @@ EuclideanDistance <- function(x, y) {
 
 # Manhattan distance
 ManhattanDistance <- function(x, y) {
-  if (class(try(LPInitialCheck(x, y))) == "try-error") {
+  if (is(try(LPInitialCheck(x, y)))[1] == "try-error") {
     return(NA)
   } else {
     # The Manhattan distance between two series is computed.
@@ -24,7 +24,7 @@ ManhattanDistance <- function(x, y) {
 
 # Infinite norm distance
 InfNormDistance <- function(x, y) {
-  if (class(try(LPInitialCheck(x, y)))=="try-error") {
+  if (is(try(LPInitialCheck(x, y)))[1]=="try-error") {
     return(NA)
   } else {
     # The supremum norm between two series is computed.
@@ -35,7 +35,7 @@ InfNormDistance <- function(x, y) {
 
 # Minkowski distance
 MinkowskiDistance <- function(x, y, p) {
-  if (class(try(LPInitialCheck(x, y, p)))=="try-error") {
+  if (is(try(LPInitialCheck(x, y, p)))[1] =="try-error") {
     return(NA)
   } else {
     # The minkowsky distance with the chosen p value is computed.
